@@ -15,17 +15,18 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "bluetoothdownloadjob.h"
+#include "connectionmultiplexer.h"
+#include "multiplexchannel.h"
 
-BluetoothDownloadJob::BluetoothDownloadJob(const QBluetoothAddress& remoteAddress, const QVariantMap& transferInfo, QObject* parent)
+BluetoothDownloadJob::BluetoothDownloadJob(ConnectionMultiplexer *connection, const QVariantMap& transferInfo, QObject* parent)
     : QObject(parent)
-    , mRemoteAddress(remoteAddress)
-    , mTransferUuid(QBluetoothUuid(transferInfo.value("uuid").toString()))
-    , mSocket(new QBluetoothSocket(QBluetoothServiceInfo::RfcommProtocol))
 {
+    QBluetoothUuid id{transferInfo.value(QStringLiteral("uuid")).toString()};
+    mSocket = QSharedPointer<MultiplexChannel>{connection->getChannel(id).release()};
 }
 
 QSharedPointer<QIODevice> BluetoothDownloadJob::payload() const
@@ -35,6 +36,4 @@ QSharedPointer<QIODevice> BluetoothDownloadJob::payload() const
 
 void BluetoothDownloadJob::start()
 {
-    connect(mSocket.data(), SIGNAL(disconnected()), this, SLOT(deleteLater()));
-    mSocket->connectToService(mRemoteAddress, mTransferUuid, QIODevice::ReadOnly);
 }
