@@ -32,9 +32,12 @@
 
 #include "indicatorhelper.h"
 
+#include "serviceregister_mac.h"
 
 IndicatorHelper::IndicatorHelper()
 {
+    registerServices();
+
     QIcon kdeconnectIcon = QIcon::fromTheme(QStringLiteral("kdeconnect"));
     QPixmap splashPixmap(kdeconnectIcon.pixmap(256, 256));
 
@@ -61,7 +64,7 @@ void IndicatorHelper::postInit()
 
 void IndicatorHelper::iconPathHook()
 {
-    const QString iconPath = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("icons"), QStandardPaths::LocateDirectory);
+    const QString iconPath = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("kdeconnect-icons"), QStandardPaths::LocateDirectory);
     if (!iconPath.isNull()) {
         QStringList themeSearchPaths = QIcon::themeSearchPaths();
         themeSearchPaths << iconPath;
@@ -134,7 +137,7 @@ void IndicatorHelper::systrayIconHook(QSystemTrayIcon &systray)
 #else
 void IndicatorHelper::systrayIconHook(KStatusNotifierItem &systray)
 {
-    const QString iconPath = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("icons"), QStandardPaths::LocateDirectory);
+    const QString iconPath = QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("kdeconnect-icons"), QStandardPaths::LocateDirectory);
     if (!iconPath.isNull()) {
         systray.setIconByName(QStringLiteral("kdeconnectindicatordark"));
     } else {
