@@ -15,24 +15,23 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "pingplugin.h"
 
-#include <KNotification>
 #include <KLocalizedString>
 #include <KPluginFactory>
 
 #include <QDebug>
 #include <QDBusConnection>
-#include <QLoggingCategory>
 
 #include <core/device.h>
+#include <core/daemon.h>
 
-K_PLUGIN_FACTORY_WITH_JSON( KdeConnectPluginFactory, "kdeconnect_ping.json", registerPlugin< PingPlugin >(); )
+#include "plugin_ping_debug.h"
 
-Q_LOGGING_CATEGORY(KDECONNECT_PLUGIN_PING, "kdeconnect.plugin.ping")
+K_PLUGIN_CLASS_WITH_JSON(PingPlugin, "kdeconnect_ping.json")
 
 PingPlugin::PingPlugin(QObject* parent, const QVariantList& args)
     : KdeConnectPlugin(parent, args)
@@ -45,38 +44,33 @@ PingPlugin::~PingPlugin()
 //     qCDebug(KDECONNECT_PLUGIN_PING) << "Ping plugin destructor for device" << device()->name();
 }
 
-bool PingPlugin::receivePackage(const NetworkPackage& np)
+bool PingPlugin::receivePacket(const NetworkPacket& np)
 {
-    KNotification* notification = new KNotification(QStringLiteral("pingReceived")); //KNotification::Persistent
-    notification->setIconName(QStringLiteral("dialog-ok"));
-    notification->setComponentName(QStringLiteral("kdeconnect"));
-    notification->setTitle(device()->name());
-    notification->setText(np.get<QString>(QStringLiteral("message"),i18n("Ping!"))); //This can be a source of spam
-    notification->sendEvent();
+    Daemon::instance()->sendSimpleNotification(QStringLiteral("pingReceived"), device()->name(), np.get<QString>(QStringLiteral("message"),i18n("Ping!")), QStringLiteral("dialog-ok"));
 
     return true;
 }
 
 void PingPlugin::sendPing()
 {
-    NetworkPackage np(PACKAGE_TYPE_PING);
-    bool success = sendPackage(np);
+    NetworkPacket np(PACKET_TYPE_PING);
+    bool success = sendPacket(np);
     qCDebug(KDECONNECT_PLUGIN_PING) << "sendPing:" << success;
 }
 
 void PingPlugin::sendPing(const QString& customMessage)
 {
-    NetworkPackage np(PACKAGE_TYPE_PING);
+    NetworkPacket np(PACKET_TYPE_PING);
     if (!customMessage.isEmpty()) {
         np.set(QStringLiteral("message"), customMessage);
     }
-    bool success = sendPackage(np);
+    bool success = sendPacket(np);
     qCDebug(KDECONNECT_PLUGIN_PING) << "sendPing:" << success;
 }
 
 QString PingPlugin::dbusPath() const
 {
-    return "/modules/kdeconnect/devices/" + device()->id() + "/ping";
+    return QStringLiteral("/modules/kdeconnect/devices/") + device()->id() + QStringLiteral("/ping");
 }
 
 #include "pingplugin.moc"
